searchData={"items":[{"type":"module","title":"TSL256X","doc":"Documentation for `TSL256x family of Ligh to digital convertors`.\n\nThis module supports TSL2560 and 2561 in both T and SC packages.\n\nTo start add the module to your mix.exs","ref":"TSL256X.html"},{"type":"function","title":"TSL256X.disable/1","doc":"Disable the sensor","ref":"TSL256X.html#disable/1"},{"type":"function","title":"TSL256X.enable/1","doc":"Enable the sensor","ref":"TSL256X.html#enable/1"},{"type":"function","title":"TSL256X.enabled?/1","doc":"Checks to see if the sensor is currently enabled.","ref":"TSL256X.html#enabled?/1"},{"type":"function","title":"TSL256X.gain/1","doc":"Gets the current `gain` setting from the sensor:\n\n* 0 - 1X\n* 1 - 16X","ref":"TSL256X.html#gain/1"},{"type":"function","title":"TSL256X.gain/2","doc":"Sets the current `gain` setting for the sensor:\n\n* 0 - 1X\n* 1 - 16X","ref":"TSL256X.html#gain/2"},{"type":"function","title":"TSL256X.integration_time/1","doc":"Gets the current `integration time` from the sensors.\n\n| value | scale | nominal integration time|\n|-----:|------:|:-----------------------:|\n|0 | 0.034 | 13.7 ms|\n|1 | 0.252 | 101 ms|\n|2 | 1 | 402 ms|\n|3 | -- | N/A|\n\nWhen the value is set to 3, manual timing control is used, check the [datasheet](assets/datasheet.pdf) for more information.","ref":"TSL256X.html#integration_time/1"},{"type":"function","title":"TSL256X.integration_time/2","doc":"Set the `integration time`, check `integration_time/1` for the possible values.","ref":"TSL256X.html#integration_time/2"},{"type":"function","title":"TSL256X.lux/1","doc":"Calculate the current light strength in lux.","ref":"TSL256X.html#lux/1"},{"type":"function","title":"Example - TSL256X.lux/1","doc":"```elixir\n   iex> TSL256X.lux(sensor)\n   2851\n```","ref":"TSL256X.html#lux/1-example"},{"type":"function","title":"TSL256X.start/2","doc":"Start the sensor and return a struct for future calls.","ref":"TSL256X.html#start/2"},{"type":"function","title":"Examples - TSL256X.start/2","doc":"```elixir\niex> TSL256X.start(\"i2c-1\", 4)\n{:ok, %TSL256X{}}\n```","ref":"TSL256X.html#start/2-examples"},{"type":"function","title":"TSL256X.stop/1","doc":"Stop the light sensor and closes the I2C bus.","ref":"TSL256X.html#stop/1"},{"type":"function","title":"Examples - TSL256X.stop/1","doc":"```elixir\niex> TSL256X.stop(sensor)\n:ok\n```","ref":"TSL256X.html#stop/1-examples"},{"type":"type","title":"TSL256X.t/0","doc":"","ref":"TSL256X.html#t:t/0"},{"type":"module","title":"TSL256X.CSPackage","doc":"Calculation for CS Package\n\nCoefficients\n------------\n\n| Ch1/Ch0 | Lux/Ch0 |\n|---------|---------|\n| 0 <= n <= 0.13| 0.0315−0.0262*(Ch1/Ch0) |\n| 0.13 <= n <= 0.26| 0.0337−0.0430*(Ch1/Ch0)|\n| 0.26 <= n <= 0.39| 0.0363−0.0529*(Ch1/Ch0)|\n| 0.39 <= n <= 0.52| 0.0392−0.0605*(Ch1/Ch0)|\n| 0.52   1.30| 0|","ref":"TSL256X.CSPackage.html"},{"type":"function","title":"TSL256X.CSPackage.calculate_lux/4","doc":"Calculate the lux value","ref":"TSL256X.CSPackage.html#calculate_lux/4"},{"type":"module","title":"TSL256X.TPackage","doc":"Calculation for T Package\n\nCoefficients\n------------\n\n| Ch1/Ch0 | Lux/Ch0 |\n|---------|---------|\n|0.00 <= n <= 0.00| 0.0304−0.0272*(Ch1/Ch0)|\n|0.125 <= n <= 0.125| 0.0325−0.0440*(Ch1/Ch0)|\n|0.250 <= n <= 0.250| 0.0351−0.0544*(Ch1/Ch0)|\n|0.375 <= n <= 0.375| 0.0381−0.0624*(Ch1/Ch0)|\n|0.50   1.30| 0|","ref":"TSL256X.TPackage.html"},{"type":"function","title":"TSL256X.TPackage.calculate_lux/4","doc":"Calculate the lux value","ref":"TSL256X.TPackage.html#calculate_lux/4"},{"type":"extras","title":"TSL256X","doc":"# TSL256X\n\nThis is a Circuits-based Elixir driver for the TSL256X family of Light-to-digital convertors.\nIt uses i2C for communication.","ref":"readme.html"},{"type":"extras","title":"Installation - TSL256X","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `tsl256x` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tsl256x, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Getting started - TSL256X","doc":"If you have I2C hooked up on your device, typically under Nerves:\n\n```elixir\niex> Circuits.I2C.detect_devices() # Use to find the right bus, eg \"i2c-1\"\n# there will be a lot of output, but one of the busses - usualy \"i2c-1\" will\n# contain the id 41, the default id this library uses.\niex> {:ok, sensor} = TSL256X.start(\"i2c-1\")\n{:ok, %TSL256X{...}}\niex> TSL256X.lux(sensor)\n2851\n```","ref":"readme.html#getting-started"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"},{"type":"extras","title":"v0.1.0 - CHANGELOG","doc":"Initial release to HEX.","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}